<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/core/RUnit.cpp" line="+273"/>
        <source>None</source>
        <translatorcomment>--exact match--
--file: it.po--
Niente
Niente: anche queste impostazioni sono andate perse ...</translatorcomment>
        <translation>Niente</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inch</source>
        <translatorcomment>--exact match--
--file: UnitSettings_it.ts--
Pollice
pollici
Microinch</translatorcomment>
        <translation>Pollice</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Foot</source>
        <translatorcomment>--exact match--
--file: it.po--
Font:
 piede
Piè pagina</translatorcomment>
        <translation>Piede</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mile</source>
        <translatorcomment>--exact match--
--file: UnitSettings_it.ts--
Miglio
 miglia quadrate
 miglio</translatorcomment>
        <translation>Miglio</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Millimeter</source>
        <translatorcomment>--exact match--
--file: qgis_it.ts--
Millimetri
Millimetri (mm)</translatorcomment>
        <translation>Millimetro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Centimeter</source>
        <translatorcomment>--exact match--
--file: UnitSettings_it.ts--
Centimetro
Centimetri (cm)</translatorcomment>
        <translation>Centimetro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Meter</source>
        <translatorcomment>--exact match--
--file: UnitSettings_it.ts--
Mostra simbolo diametro
ø (Diametro)</translatorcomment>
        <translation>Metro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Kilometer</source>
        <translatorcomment>--exact match--
--file: UnitSettings_it.ts--
Kilometro
chilometro
chilometri</translatorcomment>
        <translation>Kilometro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Microinch</source>
        <translatorcomment>--exact match--
--file: UnitSettings_it.ts--
Microinch</translatorcomment>
        <translation>Micropollice</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mil</source>
        <translatorcomment>--exact match--
--file: UnitSettings_it.ts--
Tamil
Miglio</translatorcomment>
        <translation>Millesimo di pollice</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Yard</source>
        <translatorcomment>--exact match--
--file: UnitSettings_it.ts--
Iarda</translatorcomment>
        <translation>Iarda</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Angstrom</source>
        <translatorcomment>--exact match--
--file: UnitSettings_it.ts--
Angstrom</translatorcomment>
        <translation>Angstrom</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Nanometer</source>
        <translatorcomment>--exact match--
--file: UnitSettings_it.ts--
Nanometro</translatorcomment>
        <translation>Nanometro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Micron</source>
        <translatorcomment>--exact match--
--file: UnitSettings_it.ts--
Micromillimetro</translatorcomment>
        <translation>Micromillimetro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decimeter</source>
        <translatorcomment>--exact match--
--file: UnitSettings_it.ts--
Decimetro</translatorcomment>
        <translation>Decimetro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decameter</source>
        <translatorcomment>--exact match--
--file: UnitSettings_it.ts--
Decametro</translatorcomment>
        <translation>Decametro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Hectometer</source>
        <translatorcomment>--exact match--
--file: UnitSettings_it.ts--
Ettometro</translatorcomment>
        <translation>Ettometro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Gigameter</source>
        <translatorcomment>--exact match--
--file: UnitSettings_it.ts--
Gigametro</translatorcomment>
        <translation>Gigametro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Astro</source>
        <translatorcomment>--exact match--
--file: UnitSettings_it.ts--
Astro</translatorcomment>
        <translation>Astro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Lightyear</source>
        <translatorcomment>--exact match--
--file: UnitSettings_it.ts--
Anno luce</translatorcomment>
        <translation>Anno luce</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Parsec</source>
        <translatorcomment>--exact match--
--file: UnitSettings_it.ts--
Parsec</translatorcomment>
        <translation>Parsec</translation>
    </message>
</context>
<context>
    <name>RColor</name>
    <message>
        <location filename="../src/core/RColor.cpp" line="+287"/>
        <source>By Layer</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
Da Layer
Scegli layer nella cartella</translatorcomment>
        <translation>Da Layer</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
Da Blocco</translatorcomment>
        <translation>Da Blocco</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Red</source>
        <translatorcomment>--exact match--
--file: qgis_it.ts--
&amp;Ripeti
Ripeti
Ripeti l&apos;ultima azione</translatorcomment>
        <translation>Rosso</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Yellow</source>
        <translatorcomment>--exact match--
--file: photivo_it.ts--
Giallo
giallo
Verde - giallo</translatorcomment>
        <translation>Giallo</translation>
    </message>
    <message>
        <location line="-4"/>
        <source>Green</source>
        <translatorcomment>--exact match--
--file: qgis_it.ts--
Verde
verde
Greenphone (179 x 185)</translatorcomment>
        <translation>Verde</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Cyan</source>
        <translatorcomment>--exact match--
--file: photivo_it.ts--
Cyan
Verde - ciano</translatorcomment>
        <translation>Ciano</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Blue</source>
        <translatorcomment>--exact match--
--file: qgis_it.ts--
Blu
blu
Blu - ciano</translatorcomment>
        <translation>Blu</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Magenta</source>
        <translatorcomment>--exact match--
--file: photivo_it.ts--
Magenta
Rosso - magenta</translatorcomment>
        <translation>Magenta</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Orange</source>
        <translation>Arancione</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Red</source>
        <translation>Rosso scuro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Green</source>
        <translation>Verde scuro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Blue</source>
        <translation>Blu scuro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Cyan</source>
        <translation>Scuro ciano</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Magenta</source>
        <translation>Magenta scuro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Yellow</source>
        <translation>Giallo scuro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black</source>
        <translatorcomment>--exact match--
--file: qt_it.ts--
Bianco / Nero
Nero
nero</translatorcomment>
        <translation>Nero</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>White</source>
        <translatorcomment>--exact match--
--file: photivo_it.ts--
Bianco / Nero
Bianco
bianco</translatorcomment>
        <translation>Bianco</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Gray</source>
        <translatorcomment>--exact match--
--file: qgis_it.ts--
Grigio
Grigio Chiaro</translatorcomment>
        <translation>Grigio</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Light Gray</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
Grigio Chiaro</translatorcomment>
        <translation>Grigio chiaro</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Others...</source>
        <translatorcomment>--exact match--
--file: Text_it.ts--
Altri...</translatorcomment>
        <translation>Altri...</translation>
    </message>
</context>
<context>
    <name>RDocumentVariables</name>
    <message>
        <location filename="../src/core/RDocumentVariables.cpp" line="+45"/>
        <source>Current Layer ID</source>
        <translation>ID del livello corrente</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drawing Unit</source>
        <translation>Disegno unitario</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>Scala del tipo di linea</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension Font</source>
        <translation>Carattere per quota</translation>
    </message>
</context>
<context>
    <name>REntity</name>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+92"/>
        <source>Block</source>
        <translatorcomment>--exact match--
--file: photivo_it.ts--
&amp;Blocco
Blocca
Lista Blocchi</translatorcomment>
        <translation>Blocco</translation>
    </message>
    <message>
        <source>Referenced Block</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Blocco</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="+66"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+1"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="+82"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+72"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+73"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>X</source>
        <translatorcomment>--exact match--
--file: default.po--
Uscita dall&apos;applicazione...
Uscita dall&apos;applicazione
Esportazione Disegno...</translatorcomment>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-3"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Position</source>
        <translatorcomment>--exact match--
--file: it.po--
Posizione della linea di quota o inserisci angolo:
Posizione della linea di quota o inserisci angolo
Specificare la posizione</translatorcomment>
        <translation>Posizione</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="-1"/>
        <source>Pixel Unit</source>
        <translation>Pixel unità</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Origin</source>
        <translation>Origine</translation>
    </message>
    <message>
        <location line="-1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-1"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-1"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>Y</source>
        <translatorcomment>--exact match--
--file: qgis_it.ts--
Caricamento indirizzi delle librerie...
Caricamento indirizzi delle librerie
&amp;Modifica</translatorcomment>
        <translation>Y</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+10"/>
        <source>Z</source>
        <translatorcomment>--exact match--
--file: src_shell_data_translations_ktoon_it.ts--
Affianca &amp;Orizzontalmente
Affianca Orizzontalmente
Congela tutto</translatorcomment>
        <translation>Z</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layout</source>
        <translation>Layout</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-7"/>
        <source>Scale</source>
        <translatorcomment>--exact match--
--file: locale_it_BKChem.po--
Scala</translatorcomment>
        <translation>Scala</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angle</source>
        <translatorcomment>--exact match--
--file: qgis_it.ts--
Inserisci angolo:
Inserisci angolo
Inserisci l&apos;angolo della linea di quota:</translatorcomment>
        <translation>Angolo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Columns</source>
        <translation>Colonne</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Rows</source>
        <translation>Righe</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Column Spacing</source>
        <translation>Interasse colonne</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Row Spacing</source>
        <translation>Interasse righe</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attributes</source>
        <translation>Attributi</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="+87"/>
        <location filename="../src/core/RObject.cpp" line="+66"/>
        <source>Type</source>
        <translatorcomment>--exact match--
--file: liferea-1.8-rc1.it.po--
Tipo linea:
Tipo linea
Tipo Ordinata</translatorcomment>
        <translation>Tipo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Block ID</source>
        <translation>Blocco ID</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layer</source>
        <translatorcomment>--exact match--
--file: dia.master.it.po--
&amp;Layer
Livelli
Lista Layer</translatorcomment>
        <translation>Layer</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+99"/>
        <source>Linetype</source>
        <translatorcomment>--exact match--
--file: LinetypeSettings_it.ts--
Tipo di linea di default
Tipo di linea</translatorcomment>
        <translation>Tipo di linea</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>Scala del tipo di linea</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Lineweight</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Spessore di linea</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="-2"/>
        <source>Color</source>
        <translatorcomment>--exact match--
--file: locale_it_BKChem.po--
Colori
Colore G&amp;riglia:</translatorcomment>
        <translation>Colore</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Displayed Color</source>
        <translation>Colore visualizzato</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Draw Order</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Ordine di disegno</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Boundary</source>
        <translation>Limite</translation>
    </message>
    <message>
        <location line="-3"/>
        <location filename="../src/core/RLayout.cpp" line="+3"/>
        <source>Left</source>
        <translation>Sinistra</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Bottom</source>
        <translation>Sotto</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Right</source>
        <translation>Destra</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Top</source>
        <translation>Sopra</translation>
    </message>
    <message>
        <location filename="../src/core/RObject.cpp" line="-1"/>
        <location filename="../src/core/RPropertyTypeId.cpp" line="+108"/>
        <source>Custom</source>
        <translation>Personalizzato</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Handle</source>
        <translation>Manico</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Protected</source>
        <translation>Protetta</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="+2"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
        <source>Width</source>
        <translation>Larghezza</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1"/>
        <source>Size</source>
        <translation>Dimensioni</translation>
    </message>
    <message>
        <location line="+0"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+1"/>
        <source>Height</source>
        <translation>Altezza</translation>
    </message>
    <message>
        <location filename="../src/core/RTextBasedEntity.cpp" line="-3"/>
        <source>Simple</source>
        <translation>Semplice</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Text Position</source>
        <translation>Posizione del testo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text</source>
        <translation>Testo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plain Text</source>
        <translation>Testo normale</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Font Name</source>
        <translation>Nome del font</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Height</source>
        <translation>Altezza Testo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Angle</source>
        <translation>Angolo testo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>X Scale</source>
        <translation>Scala X</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bold</source>
        <translation>Grassetto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Italic</source>
        <translation>Italico</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Line Spacing</source>
        <translation>Interasse linee</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Alignment</source>
        <translation>Allineamento</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Horizontal</source>
        <translation>Orizzontale</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Vertical</source>
        <translation>Verticale</translation>
    </message>
    <message>
        <location filename="../src/core/RViewportEntity.cpp" line="+2"/>
        <source>Rotation</source>
        <translation>Rotazione</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>On</source>
        <translation>Acceso</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Center</source>
        <translation>Visualizza centro</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Target</source>
        <translation>Visualizza obiettivo</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Overall</source>
        <translation>Overall</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="-6"/>
        <location filename="../src/core/RLayer.cpp" line="-8"/>
        <location filename="../src/core/RLayout.cpp" line="-24"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>Nascosta</translation>
    </message>
    <message>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Off</source>
        <translation>Inattivo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Frozen</source>
        <translation>Nascosto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Locked</source>
        <translation>Bloccato</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Collapsed</source>
        <translation>Piegato</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plottable</source>
        <translation>Tracciabile</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Snappable</source>
        <translation>Agganciabile</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Off is Freeze</source>
        <translation>Inattivo è congelare</translation>
    </message>
    <message>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Tab Order</source>
        <translation>Ordine di tabulazione</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Limits</source>
        <translation>Min limiti</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Limits</source>
        <translation>Max limiti</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Insertion Base</source>
        <translation>Inserimento base</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Extents</source>
        <translation>Min estensioni</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Extents</source>
        <translation>Max estensioni</translation>
    </message>
    <message>
        <source>Plot Margins</source>
        <translation type="vanished">Margini di stampa</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceData.cpp" line="+627"/>
        <source>Circular (recursive) block referencing detected:</source>
        <translation>È stato rilevato un riferimento circolare (ricorsivo) blocco:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block name:</source>
        <translation>Nome del blocco:</translation>
    </message>
</context>
<context>
    <name>RGuiAction</name>
    <message>
        <location filename="../src/core/RGuiAction.cpp" line="+184"/>
        <source>Requires selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Richiede selezione</translation>
    </message>
</context>
<context>
    <name>RLayer</name>
    <message>
        <source>Name</source>
        <translation type="vanished">Nome</translation>
    </message>
    <message>
        <source>Frozen</source>
        <translation type="vanished">Nascosto</translation>
    </message>
    <message>
        <source>Hidden</source>
        <translation type="vanished">Nascosta</translation>
    </message>
    <message>
        <source>Locked</source>
        <translation type="vanished">Bloccato</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="vanished">Colore</translation>
    </message>
    <message>
        <source>Linetype</source>
        <translation type="vanished">Tipo di linea</translation>
    </message>
    <message>
        <source>Lineweight</source>
        <translation type="vanished">Spessore di linea</translation>
    </message>
</context>
<context>
    <name>RLinetype</name>
    <message>
        <source>By Layer</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
Da Layer
Scegli layer nella cartella</translatorcomment>
        <translation type="vanished">Da Layer</translation>
    </message>
    <message>
        <source>By Block</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
Da Blocco</translatorcomment>
        <translation type="vanished">Da Blocco</translation>
    </message>
    <message>
        <source>Continuous</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
Continua
Colore continuo</translatorcomment>
        <translation type="vanished">Continua</translation>
    </message>
    <message>
        <source>Dot</source>
        <translatorcomment>--exact match--
--file: Input_it.ts--
Punti G&amp;riglia:
Punti G&amp;riglia
Punti Griglia:</translatorcomment>
        <translation type="vanished">Puntinata</translation>
    </message>
    <message>
        <source>Dot (small)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
Puntinata (Ridotta)
Trattopunto (Ridotta)</translatorcomment>
        <translation type="vanished">Puntinata (Ridotta)</translation>
    </message>
    <message>
        <source>Dot (large)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
Puntinata (Ingrandita)
Trattopunto (Ingrandita)</translatorcomment>
        <translation type="vanished">Puntinata (Ingrandita)</translation>
    </message>
    <message>
        <source>Dash</source>
        <translatorcomment>--exact match--
--file: qgis_it.ts--
Trattino
tratteggiato
Tratteggiata (Ridotta)</translatorcomment>
        <translation type="vanished">Tratteggiata</translation>
    </message>
    <message>
        <source>Dash (small)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
Tratteggiata (Ridotta)</translatorcomment>
        <translation type="vanished">Tratteggiata (Ridotta)</translation>
    </message>
    <message>
        <source>Dash (large)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
Tratteggiata (Ingrandita)</translatorcomment>
        <translation type="vanished">Tratteggiata (Ingrandita)</translation>
    </message>
    <message>
        <source>Dash Dot</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
Trattopunto
Trattopunto (Ridotta)</translatorcomment>
        <translation type="vanished">Trattopunto</translation>
    </message>
    <message>
        <source>Dash Dot (small)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
Trattopunto (Ridotta)</translatorcomment>
        <translation type="vanished">Trattopunto (Ridotta)</translation>
    </message>
    <message>
        <source>Dash Dot (large)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
Trattopunto (Ingrandita)</translatorcomment>
        <translation type="vanished">Trattopunto (Ingrandita)</translation>
    </message>
    <message>
        <source>Divide</source>
        <translatorcomment>--exact match--
--file: dia.master.it.po--
Dividi</translatorcomment>
        <translation type="vanished">Dividi</translation>
    </message>
    <message>
        <source>Divide (small)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
Dividi (Ridotta)</translatorcomment>
        <translation type="vanished">Dividi (Ridotta)</translation>
    </message>
    <message>
        <source>Divide (large)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
Dividi (Ingrandita)</translatorcomment>
        <translation type="vanished">Dividi (Ingrandita)</translation>
    </message>
    <message>
        <source>Center</source>
        <translatorcomment>--exact match--
--file: it.po--
Centro
Arco: Centro, Punto, Angoli
</translatorcomment>
        <translation type="vanished">Centro</translation>
    </message>
    <message>
        <source>Center (small)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
Centro (Ridotta)</translatorcomment>
        <translation type="vanished">Centro (Ridotta)</translation>
    </message>
    <message>
        <source>Center (large)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
Centro (Ingrandita)</translatorcomment>
        <translation type="vanished">Centro (Ingrandita)</translation>
    </message>
    <message>
        <source>Border</source>
        <translatorcomment>--exact match--
--file: qgis_it.ts--
Bordo
Margine (Ridotta)</translatorcomment>
        <translation type="vanished">Margine</translation>
    </message>
    <message>
        <source>Border (small)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
Margine (Ridotta)</translatorcomment>
        <translation type="vanished">Margine (Ridotta)</translation>
    </message>
    <message>
        <source>Border (large)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
Margine (Ingrandita)</translatorcomment>
        <translation type="vanished">Margine (Ingrandita)</translation>
    </message>
    <message>
        <location filename="../src/core/RLinetype.cpp" line="+48"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Description</source>
        <translation>Descrizione</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Metric</source>
        <translation>Metrico</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pattern</source>
        <translation>Modello</translation>
    </message>
</context>
<context>
    <name>RLinetypePattern</name>
    <message>
        <location filename="../src/core/RLinetypePattern.cpp" line="+856"/>
        <source>By Layer</source>
        <translation>Da Layer</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Da Blocco</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Continuous</source>
        <translation>Continua</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Border</source>
        <translation>Bordo</translation>
    </message>
    <message>
        <source>Border (2x)</source>
        <translation type="vanished">Margine (2x)</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Center</source>
        <translation>Centro</translation>
    </message>
    <message>
        <source>Center (2x)</source>
        <translation type="vanished">Centro (2x)</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dash dot</source>
        <translation>Tratto punto</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dashed</source>
        <translation>Tratteggiata</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Divide</source>
        <translation>Dividi</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dot</source>
        <translation>Punto</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>Nascosta</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Phantom</source>
        <translation>Fantasma</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>ISO dash</source>
        <translation>Tratto ISO</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash space</source>
        <translation>Tratto ISO spazio</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash dot</source>
        <translation>Tratto lungo ISO punti</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-dot</source>
        <translation>Tratto lungo ISO due punti</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash triple-dot</source>
        <translation>Tratto lungo ISO tre punti</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dot</source>
        <translation>Punto ISO</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash short-dash</source>
        <translation>Tratto lungo ISO tratto corto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-short-dash</source>
        <translation>Tratto lungo ISO due tratti corti</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash dot</source>
        <translation>Tratto ISO punto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash dot</source>
        <translation>Due tratti ISO punto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash double-dot</source>
        <translation>Tratto ISO due punti</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash double-dot</source>
        <translation>Linea doppia ISO punto doppio</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash triple-dot</source>
        <translation>Tratto ISO tre punti</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash triple-dot</source>
        <translation>Due tratti ISO tre punti</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Hot Water Supply</source>
        <translation>Acqua calda</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hot Water</source>
        <translation>Acqua calda</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gas Line</source>
        <translation>Gasdotto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Batting</source>
        <translation>Isolamento</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Zig Zag</source>
        <translation>Zig zag</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tracks</source>
        <translation>Binario</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 1</source>
        <translation>Limite 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 2</source>
        <translation>Limite 2</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Drainage</source>
        <translation>Drenaggio</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drainage Reversed</source>
        <translation>Drenaggio inverti</translation>
    </message>
    <message>
        <source>Drainage Reverse</source>
        <translation type="vanished">Drenaggio inverti</translation>
    </message>
</context>
<context>
    <name>RLineweight</name>
    <message>
        <location filename="../src/core/RLineweight.cpp" line="+35"/>
        <source>By Layer</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
Da Layer
Scegli layer nella cartella</translatorcomment>
        <translation>Da Layer</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
Da Blocco</translatorcomment>
        <translation>Da Blocco</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Default</source>
        <translatorcomment>--exact match--
--file: wp-geo-it_IT.po--
Unità Predefinite
Unità Predefinite:</translatorcomment>
        <translation>Predefinito</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.00mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
0.00mm</translatorcomment>
        <translation>0.00mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.05mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
0.05mm</translatorcomment>
        <translation>0.05mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.09mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
0.09mm</translatorcomment>
        <translation>0.09mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.13mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
0.13mm (ISO)</translatorcomment>
        <translation>0.13mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.15mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
0.15mm</translatorcomment>
        <translation>0.15mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.18mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
0.18mm (ISO)</translatorcomment>
        <translation>0.18mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.20mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
0.20mm</translatorcomment>
        <translation>0.20mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.25mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
0.25mm (ISO)</translatorcomment>
        <translation>0.25mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.30mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
0.30mm</translatorcomment>
        <translation>0.30mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.35mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
0.35mm (ISO)</translatorcomment>
        <translation>0.35mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.40mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
0.40mm</translatorcomment>
        <translation>0.40mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.50mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
0.50mm (ISO)</translatorcomment>
        <translation>0.50mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.53mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
0.53mm</translatorcomment>
        <translation>0.53mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.60mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
0.60mm</translatorcomment>
        <translation>0.60mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.70mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
0.70mm (ISO)</translatorcomment>
        <translation>0.70mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.80mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
0.80mm</translatorcomment>
        <translation>0.80mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.90mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
0.90mm</translatorcomment>
        <translation>0.90mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.00mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
1.00mm (ISO)</translatorcomment>
        <translation>1.00mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.06mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
1.06mm</translatorcomment>
        <translation>1.06mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.20mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
1.20mm</translatorcomment>
        <translation>1.20mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.40mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
1.40mm (ISO)</translatorcomment>
        <translation>1.40mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.58mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
1.58mm</translatorcomment>
        <translation>1.58mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.00mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
2.00mm (ISO)</translatorcomment>
        <translation>2.00mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.11mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
2.11mm</translatorcomment>
        <translation>2.11mm</translation>
    </message>
</context>
<context>
    <name>RObject</name>
    <message>
        <source>Custom</source>
        <translatorcomment>--exact match--
--file: locale_it_BKChem.po--
Nessun oggetto dimensione selezionata con una posizione di testo personalizzato.
Nessun oggetto dimensione selezionata con una posizione di testo personalizzato
Personalizzato</translatorcomment>
        <translation type="vanished">Personalizzato</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="vanished">Tipo</translation>
    </message>
    <message>
        <source>Handle</source>
        <translatorcomment>--google--
Come gestire il tosaggio
I layer non gestiti verranno persi.
I layer non gestiti verranno persi</translatorcomment>
        <translation type="vanished">Manico</translation>
    </message>
    <message>
        <source>Protected</source>
        <translation type="vanished">Protetta</translation>
    </message>
</context>
</TS>
